@@ -200,13 +200,18 @@ def handle_exceptions(function: Callable) -> Callable:
     return wrapper
 
 
-def preprocess_dashes(args: List[str]) -> List[str]:
+def preprocess_dash(arg: str) -> str:
     """Replace any dashes with tildes, otherwise argparse will assume they're options"""
-    pattern = re.compile(r"^-(?=([\w_\*]+/[\w_\*]+)|(\d+)$)")
-    processed = []
-    for arg in args:
-        processed.append(pattern.sub("~", arg))
-    return processed
+    return re.sub(r"^-(?=([\w_\*]+/[\w_\*]+)|(\d+)$)", "~", arg)
+
+
+def restore_dash(arg: str) -> str:
+    """Convert leading tildes back to dashes."""
+    return re.sub(r"^~", "-", arg)
+
+
+def process_pin_imports(input: List[str]) -> dict:
+    return dict(arg.split(":") for arg in input)
 
 
 @handle_exceptions
@@ -219,7 +224,8 @@ def main():
             detail="The current Python version is %s." % platform.python_version(),
         )
 
-    args = preprocess_dashes(sys.argv[1:])
+    # Convert leading `-` to `~` so they don't break `parse_args`
+    args = [preprocess_dash(arg) for arg in sys.argv[1:]]
     parser = create_parser()
     args = parser.parse_args(args)
 
@@ -229,6 +235,8 @@ def main():
     target = getattr(args, "target", None)
     incremental = getattr(args, "incremental", None)
 
+    pin_imports = process_pin_imports(getattr(args, "pin_imports", []))
+
     # Normally would be cleaner to handle this with an argparse mutually exclusive
     # group, but this doesn't work with --commit-ref and --remote-reset also needing
     # to be mutually exclusive, so raise the error manually.
@@ -254,71 +262,76 @@ def main():
 
     if args.command == "connect":
         run_connect(
-            args.base_url,
-            args.client_id,
-            args.client_secret,
-            args.port,
-            args.api_version,
+            base_url=args.base_url,
+            client_id=args.client_id,
+            client_secret=args.client_secret,
+            port=args.port,
+            api_version=args.api_version,
         )
     elif args.command == "sql":
         run_sql(
-            args.log_dir,
-            args.project,
-            ref,
-            args.explores,
-            args.base_url,
-            args.client_id,
-            args.client_secret,
-            args.port,
-            args.api_version,
-            args.fail_fast,
-            args.incremental,
-            args.target,
-            args.remote_reset,
-            args.concurrency,
-            args.profile,
-            args.runtime_threshold,
-            args.chunk_size,
+            log_dir=args.log_dir,
+            project=args.project,
+            ref=ref,
+            filters=[restore_dash(arg) for arg in args.explores],
+            base_url=args.base_url,
+            client_id=args.client_id,
+            client_secret=args.client_secret,
+            port=args.port,
+            api_version=args.api_version,
+            fail_fast=args.fail_fast,
+            incremental=args.incremental,
+            target=args.target,
+            remote_reset=args.remote_reset,
+            concurrency=args.concurrency,
+            profile=args.profile,
+            runtime_threshold=args.runtime_threshold,
+            chunk_size=args.chunk_size,
+            pin_imports=pin_imports,
+            ignore_hidden=args.ignore_hidden,
         )
     elif args.command == "assert":
         run_assert(
-            args.project,
-            ref,
-            args.explores,
-            args.base_url,
-            args.client_id,
-            args.client_secret,
-            args.port,
-            args.api_version,
-            args.remote_reset,
+            project=args.project,
+            ref=ref,
+            filters=[restore_dash(arg) for arg in args.explores],
+            base_url=args.base_url,
+            client_id=args.client_id,
+            client_secret=args.client_secret,
+            port=args.port,
+            api_version=args.api_version,
+            remote_reset=args.remote_reset,
+            pin_imports=pin_imports,
         )
     elif args.command == "content":
         run_content(
-            args.project,
-            ref,
-            args.explores,
-            args.base_url,
-            args.client_id,
-            args.client_secret,
-            args.port,
-            args.api_version,
-            args.remote_reset,
-            args.incremental,
-            args.target,
-            args.exclude_personal,
-            args.folders,
+            project=args.project,
+            ref=ref,
+            filters=[restore_dash(arg) for arg in args.explores],
+            base_url=args.base_url,
+            client_id=args.client_id,
+            client_secret=args.client_secret,
+            port=args.port,
+            api_version=args.api_version,
+            remote_reset=args.remote_reset,
+            incremental=args.incremental,
+            target=args.target,
+            exclude_personal=args.exclude_personal,
+            folders=[restore_dash(arg) for arg in args.folders],
+            pin_imports=pin_imports,
         )
     elif args.command == "lookml":
         run_lookml(
-            args.project,
-            ref,
-            args.base_url,
-            args.client_id,
-            args.client_secret,
-            args.port,
-            args.api_version,
-            args.remote_reset,
-            args.severity,
+            project=args.project,
+            ref=ref,
+            base_url=args.base_url,
+            client_id=args.client_id,
+            client_secret=args.client_secret,
+            port=args.port,
+            api_version=args.api_version,
+            remote_reset=args.remote_reset,
+            severity=args.severity,
+            pin_imports=pin_imports,
         )
 
     if not args.do_not_track:
@@ -489,6 +502,13 @@ def _build_validator_subparser(
             In order to test a specific commit, Spectacles will create a new branch \
             for the tests and then delete the branch when it is finished.",
     )
+    group.add_argument(
+        "--pin-imports",
+        nargs="+",
+        default=[],
+        help="Pin locally imported Looker projects to a specific ref (Git branch or commit) during validation. \
+            Provide these arguments in project_name:ref format.",
+    )
     return base_subparser
 
 
@@ -616,6 +636,11 @@ def _build_sql_subparser(
         default=500,
         help="Limit the size of explore-level queries by this number of dimensions.",
     )
+    subparser.add_argument(
+        "--ignore-hidden",
+        action="store_true",
+        help=("Exclude hidden fields from validation."),
+    )
     _build_validator_subparser(subparser_action, subparser)
     _build_select_subparser(subparser_action, subparser)
 
@@ -702,9 +727,10 @@ def run_lookml(
     api_version,
     remote_reset,
     severity,
+    pin_imports,
 ) -> None:
     client = LookerClient(base_url, client_id, client_secret, port, api_version)
-    runner = Runner(client, project, remote_reset)
+    runner = Runner(client, project, remote_reset, pin_imports)
     results = runner.validate_lookml(ref, severity)
     errors = sorted(results["errors"], key=lambda x: x["metadata"]["file_path"] or "a")
     unique_files = sorted(
@@ -750,9 +776,10 @@ def run_content(
     target,
     exclude_personal,
     folders,
+    pin_imports,
 ) -> None:
     client = LookerClient(base_url, client_id, client_secret, port, api_version)
-    runner = Runner(client, project, remote_reset)
+    runner = Runner(client, project, remote_reset, pin_imports)
     results = runner.validate_content(
         ref,
         filters,
@@ -800,9 +827,10 @@ def run_assert(
     port,
     api_version,
     remote_reset,
+    pin_imports,
 ) -> None:
     client = LookerClient(base_url, client_id, client_secret, port, api_version)
-    runner = Runner(client, project, remote_reset)
+    runner = Runner(client, project, remote_reset, pin_imports)
 
     results = runner.validate_data_tests(ref, filters)
 
@@ -812,7 +840,11 @@ def run_assert(
 
     errors = sorted(
         results["errors"],
-        key=lambda x: (x["model"], x["explore"], x["metadata"]["test_name"]),
+        key=lambda x: (
+            x["model"] or "",
+            x["explore"] or "",
+            x["metadata"]["test_name"] or "",
+        ),
     )
     if errors:
         for error in errors:
@@ -848,10 +880,12 @@ def run_sql(
     profile,
     runtime_threshold,
     chunk_size,
+    pin_imports,
+    ignore_hidden,
 ) -> None:
     """Runs and validates the SQL for each selected LookML dimension."""
     client = LookerClient(base_url, client_id, client_secret, port, api_version)
-    runner = Runner(client, project, remote_reset)
+    runner = Runner(client, project, remote_reset, pin_imports)
 
     results = runner.validate_sql(
         ref,
@@ -863,6 +897,7 @@ def run_sql(
         profile,
         runtime_threshold,
         chunk_size,
+        ignore_hidden,
     )
 
     for test in sorted(results["tested"], key=lambda x: (x["model"], x["explore"])):
