@@ -94,7 +94,7 @@ class LookerClient:
             api_version: Desired API version to use for requests.
 
         """
-        logger.debug("Authenticating Looker API credentials")
+        logger.debug(f"Authenticating to the Looker as client ID '{self.client_id}'")
 
         url = utils.compose_url(self.api_url, path=["login"])
         body = {"client_id": self.client_id, "client_secret": self.client_secret}
@@ -133,7 +133,7 @@ class LookerClient:
     @backoff.on_exception(
         backoff.expo,
         BACKOFF_EXCEPTIONS,
-        max_tries=2,
+        max_tries=3,
     )
     def request(self, method: str, url: str, *args, **kwargs) -> requests.Response:
         if self.access_token and self.access_token.expired:
@@ -373,7 +373,8 @@ class LookerClient:
                 status=response.status_code,
                 detail=(
                     f"Unable to get active branch for project '{project}'. "
-                    "Please check that the project exists and try again."
+                    "Please check that the project exists and that your user "
+                    "has the correct permissions and try again."
                 ),
                 response=response,
             )
@@ -557,7 +558,7 @@ class LookerClient:
             params["model"] = model
         if test is not None:
             params["test"] = test
-        response = self.session.get(url=url, params=params, timeout=TIMEOUT_SEC)
+        response = self.get(url=url, params=params, timeout=TIMEOUT_SEC)
 
         try:
             response.raise_for_status()
