@@ -137,13 +137,19 @@ class LookerBranchManager:
             )
         else:
             logger.debug("Creating temporary branches in imported projects")
+            previously_imported = tuple(mgr.project for mgr in self.import_managers)
             for project in self.imports:
-                import_ref = self.pin_imports.get(project, None)
-                manager = LookerBranchManager(
-                    self.client, project, pin_imports=self.pin_imports
-                )
-                manager(ref=import_ref, ephemeral=True).__enter__()
-                self.import_managers.append(manager)
+                if project not in previously_imported:
+                    import_ref = self.pin_imports.get(project, None)
+                    manager = LookerBranchManager(
+                        self.client, project, pin_imports=self.pin_imports
+                    )
+                    manager(ref=import_ref, ephemeral=True).__enter__()
+                    self.import_managers.append(manager)
+                else:
+                    logger.debug(
+                        f"Skipping project '{project}', which is already imported"
+                    )
 
         logger.indent(-1)
         logger.debug("")
@@ -446,7 +452,12 @@ class Runner:
                 "Building LookML project hierarchy for project "
                 f"'{self.project}' @ {self.branch_manager.ref}"
             )
-            project = build_project(self.client, name=self.project, filters=filters)
+            project = build_project(
+                self.client,
+                name=self.project,
+                filters=filters,
+                include_all_explores=True,
+            )
             explore_count = project.count_explores()
             print_header(
                 f"Validating content based on {explore_count} "
@@ -454,7 +465,7 @@ class Runner:
                 + (" [incremental mode] " if incremental else "")
             )
             validator.validate(project)
-            results = project.get_results(validator="content")
+            results = project.get_results(validator="content", filters=filters)
 
         if incremental and (self.branch_manager.branch or self.branch_manager.commit):
             logger.debug("Starting another content validation against the target ref")
@@ -464,10 +475,15 @@ class Runner:
                     f"'{self.project}' @ {self.branch_manager.ref}"
                 )
                 target_project = build_project(
-                    self.client, name=self.project, filters=filters
+                    self.client,
+                    name=self.project,
+                    filters=filters,
+                    include_all_explores=True,
                 )
                 validator.validate(target_project)
-                target_results = target_project.get_results(validator="content")
+                target_results = target_project.get_results(
+                    validator="content", filters=filters
+                )
 
             return self._incremental_results(base=results, target=target_results)
         else:
