@@ -1,7 +1,7 @@
 from typing import List, Optional, Any, Dict
 from spectacles.client import LookerClient
 from spectacles.exceptions import ContentError, SpectaclesException
-from spectacles.lookml import Explore, Project
+from spectacles.lookml import Explore, Project, Model
 from spectacles.logger import GLOBAL_LOGGER as logger
 from spectacles.types import JsonDict
 
@@ -60,7 +60,8 @@ class ContentValidator:
                 continue
 
             # Sometimes the content no longer exists, in which case the folder is None
-            folder_id: Optional[str] = content[content_type]["folder"].get("id")
+            folder = content[content_type].get("folder")
+            folder_id: Optional[str] = folder.get("id") if folder else None
             # If exclude_personal isn't specified, personal_folders list is empty
             if not is_folder_selected(folder_id):
                 continue
@@ -128,11 +129,13 @@ class ContentValidator:
         for error in result["errors"]:
             model_name = error["model_name"]
             explore_name = error["explore_name"]
-            explore: Optional[Explore] = project.get_explore(
-                model=model_name, name=explore_name
-            )
-            # Skip errors that are not associated with selected explores
-            if explore:
+            model: Optional[Model] = project.get_model(model_name)
+            if model:
+                explore: Optional[Explore] = model.get_explore(name=explore_name)
+            else:
+                explore = None
+            # Skip errors that are not associated with selected explores or existing models
+            if explore or model:
                 content_id = result[content_type]["id"]
                 content_error = ContentError(
                     model=model_name,
@@ -154,8 +157,11 @@ class ContentValidator:
                         else None
                     ),
                 )
-                if content_error not in explore.errors:
+                if explore and content_error not in explore.errors:
                     explore.errors.append(content_error)
                     content_errors.append(content_error)
+                elif model and content_error not in model.errors:
+                    model.errors.append(content_error)
+                    content_errors.append(content_error)
 
         return content_errors
